@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008, 2013, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2014, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -67,6 +67,8 @@ using namespace base;
 
 DEFAULT_LOG_DOMAIN(DOMAIN_WB_CONTEXT_UI)
 
+//--------------------------------------------------------------------------------------------------
+
 WBContextUI::WBContextUI(bool verbose)
   : _wb(new WBContext(this, verbose)), _command_ui(new CommandUI(_wb))
 {
@@ -74,8 +76,6 @@ WBContextUI::WBContextUI(bool verbose)
 
   base::NotificationCenter::get()->add_observer(this, "GNAppClosing");
   
-  _catalog_tree= 0;
-
   _shell_window= 0;
   
   _output_view = NULL;
@@ -102,6 +102,7 @@ WBContextUI::WBContextUI(bool verbose)
   scoped_connect(_output_view->get_be()->signal_show(),boost::bind(&WBContextUI::show_output, this));
 }
 
+//--------------------------------------------------------------------------------------------------
 
 WBContextUI::~WBContextUI()
 {
@@ -120,6 +121,9 @@ WBContextUI::~WBContextUI()
     _home_screen = NULL;
   }
 
+  delete _output_view;
+  _output_view = 0;
+
   delete _shell_window;
   _shell_window = NULL;
 
@@ -130,6 +134,7 @@ WBContextUI::~WBContextUI()
   _command_ui = NULL;
 }
 
+//--------------------------------------------------------------------------------------------------
 
 void WBContextUI::handle_notification(const std::string &name, void *sender, base::NotificationInfo &info)
 {
@@ -266,7 +271,7 @@ void WBContextUI::reset()
 
   get_physical_overview()->send_refresh_children(bec::NodeId());
   
-  _wb->get_component<WBComponentPhysical>()->update_catalog_tree();
+  _wb->get_component<WBComponentPhysical>()->update_catalog_tree_model();
 }
 
 
@@ -365,8 +370,8 @@ void WBContextUI::add_backend_builtin_commands()
 {
   _command_ui->add_builtin_command("show_about",
                                    boost::bind(&WBContextUI::show_about, this));
-  _command_ui->add_builtin_command("overview.home", // TODO: home screen should not be closable so we don't need this.
-                                  boost::bind(&WBContextUI::show_home_screen, this));
+  _command_ui->add_builtin_command("overview.home",
+                                     boost::bind(&WBContextUI::show_home_screen, this));
   _command_ui->add_builtin_command("show_output_form", 
                                   boost::bind(&WBContextUI::show_output, this));
 
@@ -392,7 +397,7 @@ void WBContextUI::add_backend_builtin_commands()
   _command_ui->add_builtin_command("web_home",
     boost::bind(&WBContextUI::show_web_page, this, "http://mysql.com/products/tools/workbench/", true));
   _command_ui->add_builtin_command("list_bugs",
-    boost::bind(&WBContextUI::show_web_page, this, "http://bugs.mysql.com/saved/WB%20bugs", true));
+    boost::bind(&WBContextUI::show_web_page, this, "http://bugs.mysql.com/saved/WBBugs", true));
  // _command_ui->add_builtin_command("plugin_site",
  //   boost::bind(&WBContextUI::show_web_page, this, "http://wb.mysql.com/addons/", true));
 //  _command_ui->add_builtin_command("check_update",
@@ -406,20 +411,7 @@ void WBContextUI::add_backend_builtin_commands()
 
 #ifndef ___specialforms
 
-//-----------------------------------------------------------------------------------
-// special forms
-
-
-bec::ValueTreeBE *WBContextUI::get_catalog_tree()
-{
-  if (!_catalog_tree)
-  {
-    WBComponentPhysical *compo= _wb->get_component<wb::WBComponentPhysical>();
-    _catalog_tree= compo->get_catalog_tree();
-  }
-  return _catalog_tree;
-}
-
+//--------------------------------------------------------------------------------------------------
 
 PhysicalOverviewBE *WBContextUI::get_physical_overview()
 {
@@ -473,6 +465,7 @@ void WBContextUI::locate_log_file()
     mforms::Utilities::open_url(base::Logger::log_dir());
 }
 
+//--------------------------------------------------------------------------------------------------
 
 void WBContextUI::show_log_file()
 {
@@ -508,6 +501,7 @@ void WBContextUI::activate_figure(const grt::ValueRef &value)
   }
 }
 
+//--------------------------------------------------------------------------------------------------
 
 void WBContextUI::form_changed()
 {  
