@@ -34,8 +34,8 @@ using namespace bec;
 using namespace wb;
 
 // Helper to wait for cache operations to finish.
-static GMutex *cache_mutex;
-static GCond *cache_condition;
+static base::Mutex cache_mutex;
+static base::Cond cache_condition;
 
 struct ac_test_entry
 {
@@ -58,7 +58,7 @@ protected:
   Sql_editor::Ref _sql_editor;
   GrtVersionRef _version;
 
-  GMutex *_connection_mutex;
+  base::RecMutex _connection_mutex;
   sql::Dbc_connection_handler::Ref _conn;
   AutoCompleteCache *_cache;
   int version;
@@ -71,24 +71,17 @@ TEST_DATA_CONSTRUCTOR(sql_editor_be_autocomplete_tests)
 
   // Auto completion needs a cache for object name look up, so we have to set up one
   // with all bells and whistles.
-  _connection_mutex = g_mutex_new();
-
-  cache_mutex = g_mutex_new();
-  cache_condition = g_cond_new();
 }
 
 TEST_DATA_DESTRUCTOR(sql_editor_be_autocomplete_tests)
 {
   _cache->shutdown();
   delete _cache;
-  g_mutex_free(_connection_mutex);
-  g_mutex_free(cache_mutex);
-  g_cond_free(cache_condition);
 }
 
-base::GMutexLock get_connection(sql::Dbc_connection_handler::Ref &conn)
+base::RecMutexLock get_connection(sql::Dbc_connection_handler::Ref &conn)
 {
-  base::GMutexLock lock(_connection_mutex);
+  base::RecMutexLock lock(_connection_mutex);
   conn = _conn;
   return lock;
 }
@@ -253,9 +246,9 @@ void cache_callback(bool working)
 {
   if (!working)
   {
-    g_mutex_lock(cache_mutex);
-    g_cond_signal(cache_condition);
-    g_mutex_unlock(cache_mutex);
+    cache_mutex.lock();
+    cache_condition.signal();
+    cache_mutex.unlock();
   }
 }
 
@@ -312,12 +305,12 @@ TEST_FUNCTION(5)
   // The loops are not necessary, but there can be spurious condition signals,
   // as the glib docs say.
   while (!_cache->is_schema_list_fetch_done())
-    g_cond_wait(cache_condition, cache_mutex);
+    cache_condition.wait(cache_mutex);
 
   _cache->get_matching_table_names("sakila"); // Cache all tables and columns.
 
   while (!_cache->is_schema_table_columns_fetch_done("sakila", "store"))
-    g_cond_wait(cache_condition, cache_mutex);
+    cache_condition.wait(cache_mutex);
 }
 
 /**
