@@ -27,6 +27,7 @@
 #include "grtdb/diff_dbobjectmatch.h"
 #include "interfaces/sqlgenerator.h"
 #include "wb_mysql_import.h"
+#include "plugins/db.mysql/backend/db_mysql_sql_export.h"
 
 #include "modules/db.mysql/src/db_mysql_diffsqlgen.h"
 
@@ -353,4 +354,194 @@ TEST_FUNCTION(10)
     ensure_equals("table comment", strrange(s, "COMMENT =", ""), "COMMENT = '"+comment_2048+"' /* comment truncated */ /*###*/");
   }
 }
+
+
+////Test for bug: 11765994, fwd view can be sometimes problematic with case sensitivity
+TEST_FUNCTION(14)
+{
+
+  {
+    grt::ValueRef e;
+    std::auto_ptr<sql::Statement> stmt(connection->createStatement());
+    NormalizedComparer cmp(tester.grt);
+    grt::DbObjectMatchAlterOmf omf;
+
+    std::string modelfile = "data/forward_engineer/view_mixed_case.mwb";
+    tester.wb->open_document(modelfile);
+    db_mysql_CatalogRef catalog = db_mysql_CatalogRef::cast_from(tester.wb->get_document()->physicalModels().get(0)->catalog());
+
+    cmp.init_omf(&omf);
+
+    boost::shared_ptr<DiffChange> create_change= diff_make(e, catalog, &omf);
+    boost::shared_ptr<DiffChange> drop_change= diff_make(catalog, e, &omf);
+
+    DictRef create_map(tester.grt);
+    DictRef drop_map(tester.grt);
+    DictRef db_opts(tester.grt);
+    grt::DictRef options(tester.grt);
+    options.set("UseFilteredLists", grt::IntegerRef(0));
+    options.set("OutputContainer", create_map);
+    options.set("CaseSensitive", grt::IntegerRef(1));
+    options.set("GenerateSchemaDrops", grt::IntegerRef(1));
+    options.set("UseShortNames", grt::IntegerRef(1));
+    options.set("GenerateUse", grt::IntegerRef(1));
+    options.set("GenerateDrops", grt::IntegerRef(1));
+    diffsql_module->generateSQL(catalog, options, create_change);
+
+    //Case sensitive in db set to true
+    db_opts.set("CaseSensitive", grt::IntegerRef(1));
+    options.set("DBSettings",db_opts);
+
+    options.set("OutputContainer", drop_map);
+    diffsql_module->generateSQL(catalog, options, drop_change);
+
+    diffsql_module->makeSQLExportScript(catalog, options, create_map, drop_map);
+    std::string export_sql_script= options.get_string("OutputScript");
+
+    std::string expected_sql = "data/forward_engineer/view_mixed_case.expected.broken.sql";
+
+    std::ifstream ref(expected_sql.c_str());
+    std::stringstream ss(export_sql_script);
+
+    std::string line, refline;
+
+    tut::ensure(expected_sql, ref.is_open());
+
+    std::string error_msg("Forward engineer of:");
+    error_msg += modelfile;
+    error_msg += " and ";
+    error_msg += expected_sql;
+    error_msg += " failed";
+
+    while (ref.good() && ss.good())
+    {
+     getline(ref, refline);
+     getline(ss, line);
+     tut::ensure_equals(error_msg, line, refline);
+    }
+
+    tester.wb->close_document();
+    tester.wb->close_document_finish();
+  }
+
+  {
+      grt::ValueRef e;
+      std::auto_ptr<sql::Statement> stmt(connection->createStatement());
+      NormalizedComparer cmp(tester.grt);
+      grt::DbObjectMatchAlterOmf omf;
+
+      std::string modelfile = "data/forward_engineer/view_mixed_case.mwb";
+      tester.wb->open_document(modelfile);
+      db_mysql_CatalogRef catalog = db_mysql_CatalogRef::cast_from(tester.wb->get_document()->physicalModels().get(0)->catalog());
+
+      cmp.init_omf(&omf);
+
+      boost::shared_ptr<DiffChange> create_change= diff_make(e, catalog, &omf);
+      boost::shared_ptr<DiffChange> drop_change= diff_make(catalog, e, &omf);
+
+      DictRef create_map(tester.grt);
+      DictRef drop_map(tester.grt);
+      DictRef db_opts(tester.grt);
+      grt::DictRef options(tester.grt);
+      options.set("UseFilteredLists", grt::IntegerRef(0));
+      options.set("OutputContainer", create_map);
+      options.set("CaseSensitive", grt::IntegerRef(1));
+      options.set("GenerateSchemaDrops", grt::IntegerRef(1));
+      options.set("UseShortNames", grt::IntegerRef(1));
+      options.set("GenerateUse", grt::IntegerRef(1));
+      options.set("GenerateDrops", grt::IntegerRef(1));
+      diffsql_module->generateSQL(catalog, options, create_change);
+
+      //Case sensitive in db set to false
+      db_opts.set("CaseSensitive", grt::IntegerRef(0));
+      options.set("DBSettings",db_opts);
+
+      options.set("OutputContainer", drop_map);
+      diffsql_module->generateSQL(catalog, options, drop_change);
+
+      diffsql_module->makeSQLExportScript(catalog, options, create_map, drop_map);
+      std::string export_sql_script= options.get_string("OutputScript");
+
+      std::string expected_sql = "data/forward_engineer/view_mixed_case.expected.good.sql";
+
+      std::ifstream ref(expected_sql.c_str());
+      std::stringstream ss(export_sql_script);
+
+      std::string line, refline;
+
+      tut::ensure(expected_sql, ref.is_open());
+
+      std::string error_msg("Forward engineer of:");
+      error_msg += modelfile;
+      error_msg += " and ";
+      error_msg += expected_sql;
+      error_msg += " failed";
+
+      while (ref.good() && ss.good())
+      {
+       getline(ref, refline);
+       getline(ss, line);
+       tut::ensure_equals(error_msg, line, refline);
+      }
+    }
+}
+
+//Test forward engineer after renaming schema if it generate proper sql
+TEST_FUNCTION(15)
+{
+  grt::ValueRef e;
+  std::auto_ptr<sql::Statement> stmt(connection->createStatement());
+  NormalizedComparer cmp(tester.grt);
+  grt::DbObjectMatchAlterOmf omf;
+
+  std::string modelfile = "data/forward_engineer/sakila_full.mwb";
+  tester.wb->open_document(modelfile);
+  db_mysql_CatalogRef catalog = db_mysql_CatalogRef::cast_from(tester.wb->get_document()->physicalModels().get(0)->catalog());
+
+
+  catalog->schemata()[0]->name("sakila_test");
+  SqlFacade::instance_for_db_obj(catalog->schemata()[0])->renameSchemaReferences(catalog, "sakila", "sakila_test");
+
+  cmp.init_omf(&omf);
+
+  boost::shared_ptr<DiffChange> create_change= diff_make(e, catalog, &omf);
+  boost::shared_ptr<DiffChange> drop_change= diff_make(catalog, e, &omf);
+
+  DictRef create_map(tester.grt);
+  DictRef drop_map(tester.grt);
+
+  grt::DictRef options = DictRef::cast_from(tester.grt->unserialize("data/forward_engineer/rename_opts.dict"));
+
+  create_map = diffsql_module->generateSQLForDifferences(GrtNamedObjectRef(), catalog, options);
+
+  diffsql_module->makeSQLExportScript(catalog, options, create_map, drop_map);
+
+  std::string export_sql_script= options.get_string("OutputScriptHeader") + options.get_string("OutputScript");
+
+  std::string expected_sql = "data/forward_engineer/sakila_name_changed.expected.sql";
+
+  std::ifstream ref(expected_sql.c_str());
+  std::stringstream ss(export_sql_script);
+
+  std::string line, refline;
+
+  tut::ensure(expected_sql, ref.is_open());
+
+  std::string error_msg("Forward engineer of:");
+  error_msg += modelfile;
+  error_msg += " and ";
+  error_msg += expected_sql;
+  error_msg += " failed";
+
+  while (ref.good() && ss.good())
+  {
+   getline(ref, refline);
+   getline(ss, line);
+   tut::ensure_equals(error_msg, line, refline);
+  }
+
+  tester.wb->close_document();
+  tester.wb->close_document_finish();
+}
+
 END_TESTS
